///File : App.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "App.hpp"
//------------------------------------------------------------------------------
IMPLEMENT_APP(App)
//------------------------------------------------------------------------------
bool App::OnInit()
{
    // Création du Handler pour les images (permet de les ouvrir)...
    wxInitAllImageHandlers();

    // Gestion de la langue
    // Ajout des préfixes possibles de chemins d'accès aux catalogues
    wxLocale::AddCatalogLookupPathPrefix(wxT("."));
    wxLocale::AddCatalogLookupPathPrefix(wxT(".."));
    wxLocale::AddCatalogLookupPathPrefix(findFile(_T("locale")));
    //wxLocale::AddCatalogLookupPathPrefix(wxStandardPaths().GetDataDir() + _T("/locale"));

    // Mise en place de la langue par défaut du système
    m_locale.Init(wxLANGUAGE_DEFAULT);
    {
       wxLogNull noLog; // Supprime les erreurs si les catalogues n'existent pas
       // Catalogue de l'application
       m_locale.AddCatalog(_T("devismaker"));
       // Catalogue de wxWidgets
       m_locale.AddCatalog(_T("wxstd"));
    }

    try
    {
        // Main frame
        m_frame = new MainFrame();
        m_frame->SetMinSize(wxSize(800, 500));
        m_frame->Show();

        #if defined USE_MULTIPLE_FILE
        for(int i = 1; i < argc; i++)
        {
            m_frame->LoadFile(argv[i]);
        }
        #else
        if(argc == 2)
        {
            m_frame->LoadFile(argv[1]);
        }
        #endif

        // SplashScreen
        int lang = wxLocale::GetSystemLanguage();
        wxString langId;

        if(lang == wxLANGUAGE_FRENCH || lang == wxLANGUAGE_FRENCH_BELGIAN || lang == wxLANGUAGE_FRENCH_CANADIAN || lang == wxLANGUAGE_FRENCH_LUXEMBOURG || lang == wxLANGUAGE_FRENCH_MONACO || lang == wxLANGUAGE_FRENCH_SWISS)
        {
            langId = _T("fr");
        }
        else
        {
            langId = _T("en");
        }

        wxString ImgFileName = findFile(_T("data/splashScreen_") + langId + _T(".png"));
        if(wxFileExists(ImgFileName))
        {
            wxImage img(ImgFileName, wxBITMAP_TYPE_PNG);
            wxSplashScreen* splash = new wxSplashScreen(wxBitmap(img), wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_TIMEOUT, 2000, m_frame, -1, wxDefaultPosition, wxDefaultSize, wxSIMPLE_BORDER|wxSTAY_ON_TOP);
        }
        Yield();
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        wxMessageBox(_("Error : ") + wxString(_T("\n")) + StrStdToWx(e.what()), _("Error..."),  wxOK | wxICON_ERROR);
        exit(1);
    }

    return true;
}
//------------------------------------------------------------------------------
int App::OnRun()
{
    bool isException = false;
    std::string msg;

    try
    {
        wxApp::OnRun();
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        isException = true;
        msg = e.what();
    }
    catch(int code)
    {
        msg = std::string("Error ") + nbToString(code) + std::string(" as occured !");
        isException = true;
    }
    catch(...)
    {
        msg = std::string("Unknown error as occured !");
        isException = true;
    }

    if(isException)
    {
        std::cerr << msg << std::endl;
        wxMessageBox(_("Fatal error : ") + wxString(_T("\n")) + StrStdToWx(msg), _("Error..."),  wxOK | wxICON_ERROR, m_frame);
        return 1;
    }
}
//------------------------------------------------------------------------------
